==> raydium-swap-sdk-0.0.2.tgz: package/src/server/index.ts <==
const express = require("express");
const bodyParser = require("body-parser");
const dotenv = require("dotenv");
dotenv.config();
import { Connection, Keypair } from "@solana/web3.js";
import RaydiumSwap, { loadPoolKeys } from "./RaydiumSwap";
import { TransferSolsBody, CalcAmountOutBody, SwapBody } from "./types";
import { transferSols, TransferSolsParams, lamportsToSol } from "./transfer";
import { convertPubkey, convertKeypair, convertNumber } from "./validate";
import { LiquidityPoolJsonInfo } from "@raydium-io/raydium-sdk";
import { swap, calcAmountOut } from "./swap";

const liquidityFile =
  process.env.LIQUIDITY_FILE ||
  "https://api.raydium.io/v2/sdk/liquidity/mainnet.json";

const rpc = process.env.RPC_URL || "https://api.mainnet-beta.solana.com";
const maxRetries = 20;
console.log(`RPC_URL: ${rpc}`);

const connection = new Connection(rpc);
let poolKeys: LiquidityPoolJsonInfo[] | undefined = undefined;

const loadPoolKeysAsync = async () => {
  if (!poolKeys || poolKeys.length === 0) {
    poolKeys = await loadPoolKeys(liquidityFile);
  }
  return poolKeys;
};

loadPoolKeysAsync();

const app = express();
app.use(bodyParser.json());

const port = process.env.PORT || 8000;

app.post("/swap", async (req, res) => {
  try {
    const { tokenA, tokenB, amountIn, direction, ownerPrikeyBs58 } =
      req.body as SwapBody;

    const amountInSols = convertNumber(amountIn);
    const owner = convertKeypair(ownerPrikeyBs58);
    const _poolKeys = await loadPoolKeysAsync();
    if (!_poolKeys || _poolKeys.length === 0) {
      throw new Error("Pool keys not loaded");
    }
    const raydiumSwap = new RaydiumSwap(rpc, owner, _poolKeys);

    const txid = await swap({
      raydiumSwap,
      tokenA,
      tokenB,
      amountIn: amountInSols,
      direction,
      maxRetries,
    });

    res.send({
      status: "ok",
      data: {
        txid,
      },
    });
  } catch (error) {
    console.error(error);
    res.status(500).send({
      status: "error",
      error: JSON.stringify(error),
    });
  }
});

app.post("/calcAmountOut", async (req, res) => {
  try {
    const { tokenA, tokenB, amountIn, direction } =
      req.body as CalcAmountOutBody;

    const amountInSols = convertNumber(amountIn);

    const tmpOwner = Keypair.generate();
    const _poolKeys = await loadPoolKeysAsync();
    if (!_poolKeys || _poolKeys.length === 0) {
      throw new Error("Pool keys not loaded");
    }
    const raydiumSwap = new RaydiumSwap(rpc, tmpOwner, _poolKeys);

    const result = await calcAmountOut({
      raydiumSwap,
      tokenA,
      tokenB,
      amountIn: amountInSols,
      direction,
    });

    res.send({
      status: "ok",
      data: result,
    });
  } catch (error) {
    console.error(error);
    res.status(500).send({
      status: "error",
      error: JSON.stringify(error),
    });
  }
});

app.post("/transferSols", async (req, res) => {
  try {
    const { fromPrikeyBs58, toPubkey, sols } = req.body as TransferSolsBody;
    const to = convertPubkey(toPubkey);
    const from = convertKeypair(fromPrikeyBs58);
    const amountSols = convertNumber(sols);

    const params: TransferSolsParams = {
      from,
      to,
      sols: amountSols,
    };
    const txId = await transferSols({
      connection,
      params,
    });

    res.send({
      status: "ok",
      data: {
        txId,
      },
    });
  } catch (error) {
    console.error(error);
    res.status(500).send({
      status: "error",
      error: JSON.stringify(error),
    });
  }
});

app.get("/balance", async (req, res) => {
  try {
    const { pubkey } = req.query;
    const publicKey = convertPubkey(pubkey as string);
    const balance = await connection.getBalance(publicKey);
    res.send({
      status: "ok",
      data: {
        balance: lamportsToSol(balance),
      },
    });
  } catch (error) {
    console.error(error);
    res.status(500).send({
      status: "error",
      error: JSON.stringify(error),
    });
  }
});

app.listen(port, () => {
  console.log(`[server]: Server is running at http://localhost:${port}`);
});

==> raydium-swap-sdk-0.0.7.tgz: package/src/server/index.ts <==
const express = require("express");
const bodyParser = require("body-parser");
const dotenv = require("dotenv");
dotenv.config();
import { Connection, Keypair } from "@solana/web3.js";
import RaydiumSwap, { loadPoolKeys } from "./RaydiumSwap";
import { TransferSolsBody, CalcAmountOutBody, SwapBody } from "./types";
import { transferSols, TransferSolsParams, lamportsToSol } from "./transfer";
import { convertPubkey, convertKeypair, convertNumber } from "./validate";
import { LiquidityPoolJsonInfo } from "@raydium-io/raydium-sdk";
import { swap, calcAmountOut } from "./swap";

const liquidityFile =
  process.env.LIQUIDITY_FILE ||
  "https://api.raydium.io/v2/sdk/liquidity/mainnet.json";

const rpc = process.env.RPC_URL || "https://api.mainnet-beta.solana.com";
const maxRetries = 20;
console.log(`RPC_URL: ${rpc}`);

const connection = new Connection(rpc);
let poolKeys: LiquidityPoolJsonInfo[] | undefined = undefined;

const loadPoolKeysAsync = async () => {
  if (!poolKeys || poolKeys.length === 0) {
    poolKeys = await loadPoolKeys(liquidityFile);
  }
  return poolKeys;
};

loadPoolKeysAsync();

const app = express();
app.use(bodyParser.json());

const port = process.env.PORT || 8000;

app.post("/swap", async (req: any, res: any) => {
  try {
    const { tokenA, tokenB, amountIn, direction, ownerPrikeyBs58 } =
      req.body as SwapBody;

    const amountInSols = convertNumber(amountIn);
    const owner = convertKeypair(ownerPrikeyBs58);
    const _poolKeys = await loadPoolKeysAsync();
    if (!_poolKeys || _poolKeys.length === 0) {
      throw new Error("Pool keys not loaded");
    }
    const raydiumSwap = new RaydiumSwap(rpc, owner, _poolKeys);

    const txid = await swap({
      raydiumSwap,
      tokenA,
      tokenB,
      amountIn: amountInSols,
      direction,
      maxRetries,
    });

    res.send({
      status: "ok",
      data: {
        txid,
      },
    });
  } catch (error) {
    console.error(error);
    res.status(500).send({
      status: "error",
      error: JSON.stringify(error),
    });
  }
});

app.post("/calcAmountOut", async (req: any, res: any) => {
  try {
    const { tokenA, tokenB, amountIn, direction } =
      req.body as CalcAmountOutBody;

    const amountInSols = convertNumber(amountIn);

    const tmpOwner = Keypair.generate();
    const _poolKeys = await loadPoolKeysAsync();
    if (!_poolKeys || _poolKeys.length === 0) {
      throw new Error("Pool keys not loaded");
    }
    const raydiumSwap = new RaydiumSwap(rpc, tmpOwner, _poolKeys);

    const result = await calcAmountOut({
      raydiumSwap,
      tokenA,
      tokenB,
      amountIn: amountInSols,
      direction,
    });

    res.send({
      status: "ok",
      data: result,
    });
  } catch (error) {
    console.error(error);
    res.status(500).send({
      status: "error",
      error: JSON.stringify(error),
    });
  }
});

app.post("/transferSols", async (req: any, res: any) => {
  try {
    const { fromPrikeyBs58, toPubkey, sols } = req.body as TransferSolsBody;
    const to = convertPubkey(toPubkey);
    const from = convertKeypair(fromPrikeyBs58);
    const amountSols = convertNumber(sols);

    const params: TransferSolsParams = {
      from,
      to,
      sols: amountSols,
    };
    const txId = await transferSols({
      connection,
      params,
    });

    res.send({
      status: "ok",
      data: {
        txId,
      },
    });
  } catch (error) {
    console.error(error);
    res.status(500).send({
      status: "error",
      error: JSON.stringify(error),
    });
  }
});

app.get("/balance", async (req: any, res: any) => {
  try {
    const { pubkey } = req.query;
    const publicKey = convertPubkey(pubkey as string);
    const balance = await connection.getBalance(publicKey);
    res.send({
      status: "ok",
      data: {
        balance: lamportsToSol(balance),
      },
    });
  } catch (error) {
    console.error(error);
    res.status(500).send({
      status: "error",
      error: JSON.stringify(error),
    });
  }
});

app.listen(port, () => {
  console.log(`[server]: Server is running at http://localhost:${port}`);
});
